-- 战令购买弹窗
Lua_WarOrderBuyExpWindow = class("Lua_WarOrderBuyExpWindow", Lua_Window);
function Lua_WarOrderBuyExpWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_WarOrderBuyExpWindow";
	self.skinName = "WarOrderBuyExpWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_WarOrderBuyExpWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_DragList.new(self.content, 548, 112, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_WarOrderBuyExpRewardItem, 112, 112, 1);
	self.rewardList:setCellSpacing(11, 0);
	self.rewardList:setRectPivot(3);
	self.rewardList:setLocation(0, 33, 0);

	self.txtInput.keyboardTypeValue = 12;
	self.txtInput.contentTypeValue = 2; -- 内容类型
	self.txtInput.characterValidationValue = 1; -- 字符验证，数字样式(1整数)
	self.txtInput.text = 1;
	self.txtInput:onEndEdit(self, self.updateCount);
	self.lessBtn:addClickFuntion(self, self.onLessBtnClick);
	self.addBtn:addClickFuntion(self, self.onAddBtnClick);
	self.sureBtn:addClickFuntion(self, self.onBuyBtnClick);
end

function Lua_WarOrderBuyExpWindow:showWin(param)
	self:superCall("showWin", param);

	local rewardVoArr = DataCenter.warOrderData.rewardVoList[self.showData.step];
	local idx = DataCenter.warOrderData.nextShowIdx;
	self.curLv = rewardVoArr[idx].show_cond;
	self.maxLv = rewardVoArr:getSize();

	self:updateShowInfo(self.curLv);
end

function Lua_WarOrderBuyExpWindow:updateShowInfo(curLv)
	self.tipsTxt.text = LanUtil.formateStr(550008, curLv);
	self.txtInput.text = curLv - self.curLv + 1;

	if self.showLv == curLv then
		return;
	end
	self.showLv = curLv;
	
	-- 当前等级奖励没达到领取，算进去
	local rewardVoArr = DataCenter.warOrderData.rewardVoList[self.showData.step];
	local startIdx = DataCenter.warOrderData.nextShowIdx;
	local endIdx = DataCenter.warOrderData.nextShowIdx + curLv - self.curLv;

	-- 要显示的道具
	local tvo;
	local tvoArr;
	local tvoInfo;
	local sortWeight = 1;
	local itemDic = {};
	for i = startIdx, endIdx do
		tvo = rewardVoArr[i].norRewardVo[1];
		tvoInfo = itemDic[tvo.id];
		if tvoInfo == nil then
			tvoInfo = {id = tvo.id, count = tvo.count, sortWeight = sortWeight};
			sortWeight = sortWeight + 1;
			itemDic[tvo.id] = tvoInfo;
		else
			tvoInfo.count = tvoInfo.count + tvo.count;
		end
 
		if not self.showData.isLock then -- 高级奖励未解锁时不显示
			tvoArr = rewardVoArr[i].advRewardVo;
			for j = 1, tvoArr:getSize() do
				tvo = tvoArr[j];
				tvoInfo = itemDic[tvo.id];
				if tvoInfo == nil then
					tvoInfo = {id = tvo.id, count = tvo.count, sortWeight = sortWeight};
					sortWeight = sortWeight + 1;
					itemDic[tvo.id] = tvoInfo;
				else
					tvoInfo.count = tvoInfo.count + tvo.count;
				end
			end
		end
	end
	local arr = Array();
	for k,v in pairs(itemDic) do
		arr:add(v);
	end
	arr:sort("sortWeight", false);

	width = (arr:getSize() - 1) * 123 + 112;
	posX = width > 548 and -274 or -width / 2;
	self.rewardList.canDrag = arr:getSize() > 4;
	self.rewardList:setArrayData(arr);
	self.rewardList:setLocation(posX, 33, 0);

	self.exp = rewardVoArr[endIdx].cond_value - DataCenter.warOrderData.curTarget;
	local info = DataCenter.warOrderUtil:getInfoByType(self.showData.curType);
	local needCount = Mathf.Round(self.exp * info.exchange_rate[2]); -- 四舍五入
	local haveCount = DataCenter.packData:getItemCountById(info.exchange_rate[1]);
	local color = haveCount >= needCount and "8F5123" or "FF0000";
	self.moneyTxt.text = LanUtil.formateStr(550009, spliceIconStrById(info.exchange_rate[1]), color, needCount);
	self.isCanBuy = haveCount >= needCount;
end

function Lua_WarOrderBuyExpWindow:updateCount()
	if self.txtInput.text == "" then
		val = 1; -- self.txtInputNum
	else
		val = tonumber(self.txtInput.text) + self.curLv - 1;
	end
	if val > self.maxLv then
		val = self.maxLv;
	elseif val < self.curLv then
		val = self.curLv;
	end
	self:updateShowInfo(val);
end

function Lua_WarOrderBuyExpWindow:onLessBtnClick(go)
	if self.showLv <= self.curLv then
		return;
	end
	self:updateShowInfo(self.showLv - 1);
end

function Lua_WarOrderBuyExpWindow:onAddBtnClick(go)
	if self.showLv >= self.maxLv then
		return;
	end
	self:updateShowInfo(self.showLv + 1);
end

function Lua_WarOrderBuyExpWindow:onBuyBtnClick()
	if self.isCanBuy then
		Lua_ProxyManager.getProxy("Lua_WarOrderProxy"):sBuyWarOrderExp(self.showData.curType, self.exp);
		self:hide();
	else
		local info = DataCenter.warOrderUtil:getInfoByType(self.showData.curType);
		DataCenter.packUtil:openPathWindow(info.exchange_rate[1])
	end
end

function Lua_WarOrderBuyExpWindow:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self:superCall("dispose");
end










Lua_WarOrderBuyExpRewardItem = class("Lua_WarOrderBuyExpRewardItem", Lua_ListCell);
function Lua_WarOrderBuyExpRewardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_WarOrderBuyExpRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.9, 0.9);
end

function Lua_WarOrderBuyExpRewardItem:setData(data)
	self._data = data;
	if data == nil then
		return;
	end

	local tvo = Lua_ToolVo.createToolVo(data.id, data.count);
	self.itemIcon:setData(tvo);
end

function Lua_WarOrderBuyExpRewardItem:onPressClick()
	if self._data == nil then
		return;
	end
	DataCenter.packUtil:showItemInfo(self.itemIcon.data);
end

function Lua_WarOrderBuyExpRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self._data = nil;
	self:superCall("dispose");
end